/* -*-c-*-
 *
 * $Id: servutil.c,v 1.5 2004/04/08 01:36:17 mdw Exp $
 *
 * Various handy server-only utilities
 *
 * (c) 2001 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of Trivial IP Encryption (TrIPE).
 *
 * TrIPE is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * TrIPE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with TrIPE; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*----- Header files ------------------------------------------------------*/

#include "tripe.h"

/*----- Global variables --------------------------------------------------*/

octet buf_i[PKBUFSZ], buf_o[PKBUFSZ], buf_t[PKBUFSZ];

/*----- Main code ---------------------------------------------------------*/

/* --- @mpstr@ --- *
 *
 * Arguments:	@mp *m@ = a multiprecision integer
 *
 * Returns:	A pointer to the integer's textual representation.
 *
 * Use:		Converts a multiprecision integer to a string.  Corrupts
 *		@buf_t@.
 */

const char *mpstr(mp *m)
{
  if (mp_writestring(m, (char *)buf_t, sizeof(buf_t), 10))
    return ("<failed>");
  return ((const char *)buf_t);
}

/* --- @gestr@ --- *
 *
 * Arguments:	@group *g@ = a group
 *		@ge *x@ = a group element
 *
 * Returns:	A pointer to the element's textual representation.
 *
 * Use:		Converts a group element to a string.  Corrupts
 *		@buf_t@.
 */

const char *gestr(group *g, ge *x)
{
  if (group_writestring(g, x, (char *)buf_t, sizeof(buf_t)))
    return ("<failed>");
  return ((const char *)buf_t);
}

/* --- @timestr@ --- *
 *
 * Arguments:	@time_t t@ = a time to convert
 *
 * Returns:	A pointer to a textual representation of the time.
 *
 * Use:		Converts a time to a textual representation.  Corrupts
 *		@buf_t@.
 */

const char *timestr(time_t t)
{
  struct tm *tm;
  if (!t)
    return ("NEVER");
  tm = localtime(&t);
  strftime((char *)buf_t, sizeof(buf_t), "%Y-%m-%dT%H:%M:%S", tm);
  return ((const char *)buf_t);
}

/*----- That's all, folks -------------------------------------------------*/
